OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не можу писати у каталог \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Зазвичай це можна виправити, надавши веб-серверу права на запис в теці конфігурації",
    "See %s" : "Переглянути %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Зазвичай це можна виправити, %sнадавши веб-серверу права на запис в теці конфігурації%s.",
    "Sample configuration detected" : "Виявлено приклад конфігурації",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Було виявлено, що приклад конфігурації було скопійовано. Це може нашкодити вашій системі та не підтримується. Будь ласка, зверніться до документації перед внесенням змін в файл config.php",
    "PHP %s or higher is required." : "Необхідно PHP %s або вище",
    "PHP with a version lower than %s is required." : "Потрібна версія PHP нижче %s ",
    "Following databases are supported: %s" : "Підтримуються наступні сервери баз даних: %s",
    "The command line tool %s could not be found" : "Утиліту командного рядка %s не знайдено",
    "The library %s is not available." : "Бібліотека %s недоступна.",
    "Library %s with a version higher than %s is required - available version %s." : "Потрібна бібліотека %s версії не більше %s, встановлена версія %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Потрібна бібліотека %s версії менш ніж %s, встановлена версія %s.",
    "Following platforms are supported: %s" : "Підтримуються наступні платформи: %s",
    "ownCloud %s or higher is required." : "Потрібен ownCloud %s або вище.",
    "ownCloud %s or lower is required." : "Потрібна версія %s ownCloud або нижча.",
    "Unknown filetype" : "Невідомий тип файлу",
    "Invalid image" : "Невірне зображення",
    "today" : "сьогодні",
    "yesterday" : "вчора",
    "_%n day ago_::_%n days ago_" : ["%n день тому","%n днів тому","%n днів тому"],
    "last month" : "минулого місяця",
    "last year" : "минулого року",
    "_%n year ago_::_%n years ago_" : ["%n рік тому","%n років тому","%n років тому"],
    "seconds ago" : "секунди тому",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль з id: %s не існує. Будь ласка, увімкніть його в налаштуваннях програми або зверніться до адміністратора.",
    "Empty filename is not allowed" : "Порожні імена файлів не допускаються",
    "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
    "4-byte characters are not supported in file names" : "4-х байтові символи в імені файлів не допустимі",
    "File name is a reserved word" : "Ім’я файлу є зарезервованим словом",
    "File name contains at least one invalid character" : "Ім’я файлу містить принаймні один некоректний символ",
    "File name is too long" : "Ім’я файлу занадто довге",
    "App directory already exists" : "Тека додатку вже існує",
    "Can't create app folder. Please fix permissions. %s" : "Неможливо створити теку додатку. Будь ласка, виправте права доступу. %s",
    "Archive does not contain a directory named %s" : "Архів не містить теки з назвою %s",
    "No source specified when installing app" : "Не вказано джерело при встановлені додатку",
    "No href specified when installing app from http" : "Не вказано атрибут href при встановлені додатку з http",
    "No path specified when installing app from local file" : "Не вказано шлях при встановлені додатку з локального файлу",
    "Archives of type %s are not supported" : "Архіви %s не підтримуються",
    "Failed to open archive when installing app" : "Неможливо відкрити архів при встановлені додатку",
    "App does not provide an info.xml file" : "Додаток не має файл info.xml",
    "App cannot be installed because appinfo file cannot be read." : "Додаток не може бути встановлений через те, що файл appinfo не може бути прочитано.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Підпис не може бути перевірено. Будь ласка, зверніться до розробника додатку і перевірте сторінку адміністрування.",
    "App can't be installed because of not allowed code in the App" : "Неможливо встановити додаток. Він містить заборонений код",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Неможливо встановити додаток, він є несумісним з даною версією ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Неможливо встановити додаток, оскільки він містить параметр <shipped>true</shipped> заборонений додаткам, що не входять в поставку ",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Неможливо встановити додаток. Версія в файлі info.xml не співпадає з заявленою в магазині додатків",
    "%s enter the database username and name." : "%s введіть назву бази даних та ім'я користувача.",
    "%s enter the database username." : "%s введіть ім'я користувача бази даних.",
    "%s enter the database name." : "%s введіть назву бази даних.",
    "%s you may not use dots in the database name" : "%s не можна використовувати крапки в назві бази даних",
    "Oracle connection could not be established" : "Не можемо з'єднатися з Oracle ",
    "Oracle username and/or password not valid" : "Oracle ім'я користувача та/або пароль не дійсні",
    "DB Error: \"%s\"" : "Помилка БД: \"%s\"",
    "Offending command was: \"%s\"" : "Команда, що викликала проблему: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Вам потрібно ввести або існуючий обліковий запис або administrator.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Команда, що викликала проблему: \"%s\", ім'я: %s, пароль: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL ім'я користувача та/або пароль не дійсні",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не підтримується і %s не буде коректно працювати на цій платформі. Випробовуєте на свій риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання GNU/Linux серверу",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Здається що екземпляр цього %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, видаліть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
    "Set an admin username." : "Встановіть ім'я адміністратора.",
    "Set an admin password." : "Встановіть пароль адміністратора.",
    "Can't create or write into the data directory %s" : "Неможливо створити або записати каталог даних %s",
    "Invalid Federated Cloud ID" : "Неправильний Об'єднаний Хмарний Ідентіфікатор ",
    "%s shared »%s« with you" : "%s поділився »%s« з вами",
    "%s via %s" : "%s за допомогою %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Не вдалося поділитися %s, загальний доступ не допускає публікації з елементів типу %i",
    "Sharing %s failed, because the file does not exist" : "Не вдалося поділитися %s, оскільки файл не існує",
    "You are not allowed to share %s" : "Вам заборонено поширювати %s",
    "Sharing %s failed, because you can not share with yourself" : "Не вдалося поділитися %s, оскільки ви не можете ділитись самі з собою",
    "Sharing %s failed, because the user %s does not exist" : "Не вдалося поділитися з %s, оскільки користувач %s не існує",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Не вдалося поділитися %s, оскільки користувач %s не є членом будь-якої групи в яку входить %s",
    "Sharing %s failed, because this item is already shared with %s" : "Не вдалося поділитися %s, оскільки файл вже в загальному доступі з %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Не вдалося поділитися %s, оскільки %s вже має до нього доступ",
    "Sharing %s failed, because the group %s does not exist" : "Не вдалося поділитися %s, оскільки група %s не існує",
    "Sharing %s failed, because %s is not a member of the group %s" : "Не вдалося поділитися %s, оскільки %s не є членом групи %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Вам необхідно задати пароль для створення публічного посилання. Дозволені лише захищені посилання",
    "Sharing %s failed, because sharing with links is not allowed" : "Не вдалося поділитися %s, оскільки публічний доступ через посилання заборонений",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Не вдалося поділитися %s, не вдалося знайти %s, можливо, сервер не доступний.",
    "Share type %s is not valid for %s" : "Тип загального доступу %s неприпустимий для %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Не вдалося налаштувати права доступу для %s, зазначені права доступу перевищують надані для %s",
    "Setting permissions for %s failed, because the item was not found" : "Не вдалося налаштувати права доступу для %s, елемент не знайдений.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Неможливо встановити дату закінчення. Загальні ресурси не можуть застаріти пізніше %s з моменту їх публікації.",
    "Cannot set expiration date. Expiration date is in the past" : "Неможливо встановити дату закінчення. Дата закінчення в минулому.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Неможливо очистити дату закінчення. Загальні ресурси повинні мати термін придатності.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend загального доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend загального доступу %s не знайдено",
    "Sharing backend for %s not found" : "Бекенд загального доступу для %s не знайдено",
    "Sharing failed, because the user %s is the original sharer" : "Не вдалося поділитися, оскільки %s є тим хто поділився з самого початку",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Не вдалося поділитися %s, права перевищують надані права доступу %s",
    "Sharing %s failed, because resharing is not allowed" : "Не вдалося поділитися %s, перевідкриття доступу заборонено",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Не вдалося поділитися %s, backend загального доступу не знайшов шлях до %s",
    "Sharing %s failed, because the file could not be found in the file cache" : "Не вдалося поділитися %s, елемент не знайдено у файловому кеші.",
    "Cannot increase permissions of %s" : "Не вдалося підвищити дозволи для %s",
    "Files can't be shared with delete permissions" : "Неможливо поділитись файлами з дозволом на видалення",
    "Files can't be shared with create permissions" : "Неможливо поділитись файлами з дозволом на створення",
    "Expiration date is in the past" : "Дата закінчення в минулому",
    "Cannot set expiration date more than %s days in the future" : "Неможливо встановити дату закінчення далі ніж %s днів у майбутньому",
    "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
    "Apps" : "Додатки",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Тільки такі символи допускаються в імені користувача: \"a-z\", \"A-Z\", \"0-9\", і \"_.@-'\"",
    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
    "Username contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу в початку або в кінці",
    "A valid password must be provided" : "Потрібно задати вірний пароль",
    "The username is already being used" : "Ім'я користувача вже використовується",
    "Login canceled by app" : "Вхід скасовано додатком",
    "User disabled" : "Користувач виключений",
    "Help" : "Допомога",
    "Personal" : "Особисте",
    "Users" : "Користувачі",
    "Admin" : "Адмін",
    "Recommended" : "Рекомендуємо",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Додаток \"%s\" не може бути встановлений через те, що файл appinfo не може бути прочитано.",
    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Додаток \"%s\" не може бути встановлено, так як він не сумісний з цією версією ownCloud.",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Додаток \"%s\" не може бути встановлений, так як наступні залежності не виконано: %s",
    "No app name specified" : "Не вказано ім'я додатку",
    "web services under your control" : "підконтрольні Вам веб-сервіси",
    "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
    "Can't read file" : "Не можливо прочитати файл",
    "Application is not enabled" : "Додаток не увімкнений",
    "Authentication error" : "Помилка автентифікації",
    "Token expired. Please reload page." : "Строк дії токена скінчився. Будь ласка, перезавантажте сторінку.",
    "Unknown user" : "Невідомий користувач",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Не встановлено драйвер бази даних (sqlite, mysql, or postgresql).",
    "Microsoft Windows Platform is not supported" : "Платформа Microsoft Windows не підтримується",
    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Запуск сервера ownCloud на платформі Microsoft Windows не підтримується. Ми пропонуємо використати сервер на базі Linux у віртуальній машині, якщо у вас немає можливості мігрувати увесь сервер. Знайдіть пакунки для Linux, а також прості у впровадженні образи віртуальних машин на <a href=\"%s\">%s</a>. При міграції існуючих встановлень на Linux ви можете використати деякі поради та скрипт міграції з <a href=\"%s\">нашій документації</a>.",
    "Cannot write into \"config\" directory" : "Не можу писати у теку \"config\"",
    "Cannot write into \"apps\" directory" : "Не можу писати у теку \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Зазвичай це можна виправити, %s надавши веб-серверу права на запис в каталог додатків %s або відключивши сховище програм у файлі конфігурації.",
    "Cannot create \"data\" directory (%s)" : "Неможливо створити каталог \"data\" (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Зазвичай це можна виправити <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">надавши веб-серверу права на запис в кореневому каталозі</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Зазвичай це можна виправити, %s надавши веб-серверу права на запис в кореневому каталозі %s.",
    "Setting locale to %s failed" : "Установка локалі %s не вдалася",
    "Please install one of these locales on your system and restart your webserver." : "Встановіть один із цих мовних пакетів в вашу систему і перезапустіть веб-сервер.",
    "Please ask your server administrator to install the module." : "Будь ласка, зверніться до адміністратора, щоб встановити модуль.",
    "PHP module %s not installed." : "%s модуль PHP не встановлено.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Параметр PHP \"%s\" не встановлено в \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Установка цього параметру в php.ini дозволяє запуститися ownCloud знову.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload налаштовано як \"%s\" замість очікуваного значення \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Для виправлення змініть <code>mbstring.func_overload</code> на <code>0</code> у вашому php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Необхідно libxml2 версії принаймні 2.7.0. На разі встановлена %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Що виправити це оновіть версію libxml2 та перезапустіть веб-сервер.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на вичищення блоків вбудованої документації. Це зробить кілька основних додатків недоступними.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Модулі PHP були встановлені, але вони все ще перераховані як відсутні?",
    "Please ask your server administrator to restart the web server." : "Будь ласка, зверніться до адміністратора, щоб перезавантажити сервер.",
    "PostgreSQL >= 9 required" : "Потрібно PostgreSQL> = 9",
    "Please upgrade your database version" : "Оновіть версію бази даних",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
    "Data directory (%s) is readable by other users" : "Каталог даних (%s) доступний для читання іншим користувачам",
    "Data directory (%s) must be an absolute path" : "Тека з даними (%s) має бути задана абсолютним шляхом",
    "Check the value of \"datadirectory\" in your configuration" : "Перевірте значення \"datadirectory\" у своїй конфігурації",
    "Data directory (%s) is invalid" : "Каталог даних (%s) невірний",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Переконайтеся, що файл \".ocdata\" присутній у корені каталогу даних.",
    "Could not obtain lock type %d on \"%s\"." : "Не вдалося отримати блокування типу %d для \"%s\"",
    "Storage unauthorized. %s" : "Сховище не авторизовано. %s",
    "Storage incomplete configuration. %s" : "Неповна конфігурація сховища. %s",
    "Storage connection error. %s" : "Помилка з'єднання зі сховищем. %s",
    "Storage not available" : "Сховище не доступне",
    "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
